==> ifrit_3.3.4.orig.tar.gz: ifrit-3.3.4/help/iimagefactorydata1.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2011 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iimagefactory.h"
#include "istring.h"

#include <stdlib.h>


namespace iImageFactory_Private
{
	class List;
	void CreateData(const iString &dirname, const iString &outname, const char *sel);
	void ReadData(int num, bool isBigEndianData, const iImageFactory::ByteData *data, List &list);

	void LoadData1(List &list)
	{
#include "iimagefactorydata1.h"

		if(num == 0)
		{
			CreateData("Work/images","Code/help/iimagefactorydata1.h","az");
			exit(0);
		}

		ReadData(num,isBigEndianData,data,list);
	}
};

==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/help/iimagefactorydata1.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iconsole.h"
#include "iimagefactory.h"
#include "istring.h"

#include <stdlib.h>


namespace iImageFactory_Private
{
	class List;
	void CreateData(const iString &dirname, const iString &outname, const char *sel);
	void ReadData(int num, bool isBigEndianData, const iImageFactory::ByteData *data, List &list);

	void LoadData1(List &list)
	{
#include "iimagefactorydata1.h"

		if(num == 0)
		{
			CreateData("Work/images","Code/help/iimagefactorydata1.h","az");
			iConsole::Display(iConsole::_Warning,"IFrIT is creating compressed help data...\nPlease compile again and re-run.");
			exit(0);
		}

		ReadData(num,isBigEndianData,data,list);
	}
};
